# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

accountId: Optional[str]

adminApiKey: Optional[str]

apiKey: Optional[str]

apiUrl: Optional[str]

cacertFile: Optional[str]

infrastructureApiUrl: Optional[str]

insecureSkipVerify: Optional[bool]

insightsInsertKey: Optional[str]

insightsInsertUrl: Optional[str]

insightsQueryUrl: Optional[str]

nerdgraphApiUrl: Optional[str]

region: str
"""
The data center for which your New Relic account is configured. Only one region per provider block is permitted.
"""

syntheticsApiUrl: Optional[str]




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['DataPartitionRuleArgs', 'DataPartitionRule']

@pulumi.input_type
class DataPartitionRuleArgs:
    def __init__(__self__, *,
                 enabled: pulumi.Input[_builtins.bool],
                 nrql: pulumi.Input[_builtins.str],
                 retention_policy: pulumi.Input[_builtins.str],
                 target_data_partition: pulumi.Input[_builtins.str],
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a DataPartitionRule resource.
        :param pulumi.Input[_builtins.bool] enabled: Whether or not this data partition rule is enabled.
        :param pulumi.Input[_builtins.str] nrql: The NRQL to match events for this data partition rule. Logs matching this criteria will be routed to the specified data partition.
        :param pulumi.Input[_builtins.str] retention_policy: The retention policy of the data partition data. Valid values are `SECONDARY` and `STANDARD`.
        :param pulumi.Input[_builtins.str] target_data_partition: The name of the data partition where logs will be allocated once the rule is enabled.
        :param pulumi.Input[_builtins.str] account_id: The account id associated with the data partition rule.
        :param pulumi.Input[_builtins.str] description: The description of the data partition rule.
        """
        pulumi.set(__self__, "enabled", enabled)
        pulumi.set(__self__, "nrql", nrql)
        pulumi.set(__self__, "retention_policy", retention_policy)
        pulumi.set(__self__, "target_data_partition", target_data_partition)
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if description is not None:
            pulumi.set(__self__, "description", description)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> pulumi.Input[_builtins.bool]:
        """
        Whether or not this data partition rule is enabled.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: pulumi.Input[_builtins.bool]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter
    def nrql(self) -> pulumi.Input[_builtins.str]:
        """
        The NRQL to match events for this data partition rule. Logs matching this criteria will be routed to the specified data partition.
        """
        return pulumi.get(self, "nrql")

    @nrql.setter
    def nrql(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "nrql", value)

    @_builtins.property
    @pulumi.getter(name="retentionPolicy")
    def retention_policy(self) -> pulumi.Input[_builtins.str]:
        """
        The retention policy of the data partition data. Valid values are `SECONDARY` and `STANDARD`.
        """
        return pulumi.get(self, "retention_policy")

    @retention_policy.setter
    def retention_policy(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "retention_policy", value)

    @_builtins.property
    @pulumi.getter(name="targetDataPartition")
    def target_data_partition(self) -> pulumi.Input[_builtins.str]:
        """
        The name of the data partition where logs will be allocated once the rule is enabled.
        """
        return pulumi.get(self, "target_data_partition")

    @target_data_partition.setter
    def target_data_partition(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "target_data_partition", value)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The account id associated with the data partition rule.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the data partition rule.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)


@pulumi.input_type
class _DataPartitionRuleState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 deleted: Optional[pulumi.Input[_builtins.bool]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 nrql: Optional[pulumi.Input[_builtins.str]] = None,
                 retention_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 target_data_partition: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering DataPartitionRule resources.
        :param pulumi.Input[_builtins.str] account_id: The account id associated with the data partition rule.
        :param pulumi.Input[_builtins.bool] deleted: Whether or not this data partition rule is deleted. Deleting a data partition rule does not delete the already persisted data. This data will be retained for a given period of time specified in the retention policy field.
        :param pulumi.Input[_builtins.str] description: The description of the data partition rule.
        :param pulumi.Input[_builtins.bool] enabled: Whether or not this data partition rule is enabled.
        :param pulumi.Input[_builtins.str] nrql: The NRQL to match events for this data partition rule. Logs matching this criteria will be routed to the specified data partition.
        :param pulumi.Input[_builtins.str] retention_policy: The retention policy of the data partition data. Valid values are `SECONDARY` and `STANDARD`.
        :param pulumi.Input[_builtins.str] target_data_partition: The name of the data partition where logs will be allocated once the rule is enabled.
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if deleted is not None:
            pulumi.set(__self__, "deleted", deleted)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if nrql is not None:
            pulumi.set(__self__, "nrql", nrql)
        if retention_policy is not None:
            pulumi.set(__self__, "retention_policy", retention_policy)
        if target_data_partition is not None:
            pulumi.set(__self__, "target_data_partition", target_data_partition)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The account id associated with the data partition rule.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter
    def deleted(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether or not this data partition rule is deleted. Deleting a data partition rule does not delete the already persisted data. This data will be retained for a given period of time specified in the retention policy field.
        """
        return pulumi.get(self, "deleted")

    @deleted.setter
    def deleted(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "deleted", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The description of the data partition rule.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether or not this data partition rule is enabled.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter
    def nrql(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The NRQL to match events for this data partition rule. Logs matching this criteria will be routed to the specified data partition.
        """
        return pulumi.get(self, "nrql")

    @nrql.setter
    def nrql(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "nrql", value)

    @_builtins.property
    @pulumi.getter(name="retentionPolicy")
    def retention_policy(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The retention policy of the data partition data. Valid values are `SECONDARY` and `STANDARD`.
        """
        return pulumi.get(self, "retention_policy")

    @retention_policy.setter
    def retention_policy(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "retention_policy", value)

    @_builtins.property
    @pulumi.getter(name="targetDataPartition")
    def target_data_partition(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the data partition where logs will be allocated once the rule is enabled.
        """
        return pulumi.get(self, "target_data_partition")

    @target_data_partition.setter
    def target_data_partition(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "target_data_partition", value)


@pulumi.type_token("newrelic:index/dataPartitionRule:DataPartitionRule")
class DataPartitionRule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 nrql: Optional[pulumi.Input[_builtins.str]] = None,
                 retention_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 target_data_partition: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Use this resource to create, update and delete New Relic Data partition rule.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.DataPartitionRule("foo",
            description="description",
            enabled=True,
            nrql="logtype='node'",
            retention_policy="STANDARD",
            target_data_partition="Log_name")
        ```

        ## Additional Information

        More details about the data partition can be found [here](https://docs.newrelic.com/docs/logs/ui-data/data-partitions/)

        ## Import

        New Relic data partition rule can be imported using the rule ID, e.g.

        bash

        ```sh
        $ pulumi import newrelic:index/dataPartitionRule:DataPartitionRule foo <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: The account id associated with the data partition rule.
        :param pulumi.Input[_builtins.str] description: The description of the data partition rule.
        :param pulumi.Input[_builtins.bool] enabled: Whether or not this data partition rule is enabled.
        :param pulumi.Input[_builtins.str] nrql: The NRQL to match events for this data partition rule. Logs matching this criteria will be routed to the specified data partition.
        :param pulumi.Input[_builtins.str] retention_policy: The retention policy of the data partition data. Valid values are `SECONDARY` and `STANDARD`.
        :param pulumi.Input[_builtins.str] target_data_partition: The name of the data partition where logs will be allocated once the rule is enabled.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DataPartitionRuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Use this resource to create, update and delete New Relic Data partition rule.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.DataPartitionRule("foo",
            description="description",
            enabled=True,
            nrql="logtype='node'",
            retention_policy="STANDARD",
            target_data_partition="Log_name")
        ```

        ## Additional Information

        More details about the data partition can be found [here](https://docs.newrelic.com/docs/logs/ui-data/data-partitions/)

        ## Import

        New Relic data partition rule can be imported using the rule ID, e.g.

        bash

        ```sh
        $ pulumi import newrelic:index/dataPartitionRule:DataPartitionRule foo <id>
        ```

        :param str resource_name: The name of the resource.
        :param DataPartitionRuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DataPartitionRuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 nrql: Optional[pulumi.Input[_builtins.str]] = None,
                 retention_policy: Optional[pulumi.Input[_builtins.str]] = None,
                 target_data_partition: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DataPartitionRuleArgs.__new__(DataPartitionRuleArgs)

            __props__.__dict__["account_id"] = account_id
            __props__.__dict__["description"] = description
            if enabled is None and not opts.urn:
                raise TypeError("Missing required property 'enabled'")
            __props__.__dict__["enabled"] = enabled
            if nrql is None and not opts.urn:
                raise TypeError("Missing required property 'nrql'")
            __props__.__dict__["nrql"] = nrql
            if retention_policy is None and not opts.urn:
                raise TypeError("Missing required property 'retention_policy'")
            __props__.__dict__["retention_policy"] = retention_policy
            if target_data_partition is None and not opts.urn:
                raise TypeError("Missing required property 'target_data_partition'")
            __props__.__dict__["target_data_partition"] = target_data_partition
            __props__.__dict__["deleted"] = None
        super(DataPartitionRule, __self__).__init__(
            'newrelic:index/dataPartitionRule:DataPartitionRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[_builtins.str]] = None,
            deleted: Optional[pulumi.Input[_builtins.bool]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            nrql: Optional[pulumi.Input[_builtins.str]] = None,
            retention_policy: Optional[pulumi.Input[_builtins.str]] = None,
            target_data_partition: Optional[pulumi.Input[_builtins.str]] = None) -> 'DataPartitionRule':
        """
        Get an existing DataPartitionRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: The account id associated with the data partition rule.
        :param pulumi.Input[_builtins.bool] deleted: Whether or not this data partition rule is deleted. Deleting a data partition rule does not delete the already persisted data. This data will be retained for a given period of time specified in the retention policy field.
        :param pulumi.Input[_builtins.str] description: The description of the data partition rule.
        :param pulumi.Input[_builtins.bool] enabled: Whether or not this data partition rule is enabled.
        :param pulumi.Input[_builtins.str] nrql: The NRQL to match events for this data partition rule. Logs matching this criteria will be routed to the specified data partition.
        :param pulumi.Input[_builtins.str] retention_policy: The retention policy of the data partition data. Valid values are `SECONDARY` and `STANDARD`.
        :param pulumi.Input[_builtins.str] target_data_partition: The name of the data partition where logs will be allocated once the rule is enabled.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DataPartitionRuleState.__new__(_DataPartitionRuleState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["deleted"] = deleted
        __props__.__dict__["description"] = description
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["nrql"] = nrql
        __props__.__dict__["retention_policy"] = retention_policy
        __props__.__dict__["target_data_partition"] = target_data_partition
        return DataPartitionRule(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[_builtins.str]:
        """
        The account id associated with the data partition rule.
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter
    def deleted(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether or not this data partition rule is deleted. Deleting a data partition rule does not delete the already persisted data. This data will be retained for a given period of time specified in the retention policy field.
        """
        return pulumi.get(self, "deleted")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The description of the data partition rule.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether or not this data partition rule is enabled.
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter
    def nrql(self) -> pulumi.Output[_builtins.str]:
        """
        The NRQL to match events for this data partition rule. Logs matching this criteria will be routed to the specified data partition.
        """
        return pulumi.get(self, "nrql")

    @_builtins.property
    @pulumi.getter(name="retentionPolicy")
    def retention_policy(self) -> pulumi.Output[_builtins.str]:
        """
        The retention policy of the data partition data. Valid values are `SECONDARY` and `STANDARD`.
        """
        return pulumi.get(self, "retention_policy")

    @_builtins.property
    @pulumi.getter(name="targetDataPartition")
    def target_data_partition(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the data partition where logs will be allocated once the rule is enabled.
        """
        return pulumi.get(self, "target_data_partition")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ApplicationSettingsArgs', 'ApplicationSettings']

@pulumi.input_type
class ApplicationSettingsArgs:
    def __init__(__self__, *,
                 app_apdex_threshold: Optional[pulumi.Input[_builtins.float]] = None,
                 enable_real_user_monitoring: Optional[pulumi.Input[_builtins.bool]] = None,
                 enable_slow_sql: Optional[pulumi.Input[_builtins.bool]] = None,
                 enable_thread_profiler: Optional[pulumi.Input[_builtins.bool]] = None,
                 end_user_apdex_threshold: Optional[pulumi.Input[_builtins.float]] = None,
                 error_collectors: Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationSettingsErrorCollectorArgs']]]] = None,
                 guid: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 tracer_type: Optional[pulumi.Input[_builtins.str]] = None,
                 transaction_tracers: Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationSettingsTransactionTracerArgs']]]] = None,
                 use_server_side_config: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a ApplicationSettings resource.
        :param pulumi.Input[_builtins.float] app_apdex_threshold: The acceptable response time limit (Apdex threshold) for the application.
        :param pulumi.Input[_builtins.bool] enable_real_user_monitoring: Dummy field to support backward compatibility of previous version.should be removed with next major version.
        :param pulumi.Input[_builtins.bool] enable_slow_sql: Enable or disable the collection of slowest database queries in your traces.
        :param pulumi.Input[_builtins.bool] enable_thread_profiler: Enable or disable the collection of thread profiling data.
        :param pulumi.Input[_builtins.float] end_user_apdex_threshold: Dummy field to support backward compatibility of previous version.should be removed with next major version.
        :param pulumi.Input[Sequence[pulumi.Input['ApplicationSettingsErrorCollectorArgs']]] error_collectors: Configuration block for error collection. Including this block enables the error collector. The following arguments are supported:
        :param pulumi.Input[_builtins.str] guid: The GUID of the application in New Relic APM.
               
               > **NOTE:** While the attribute `guid` is not mandatory at a schema level, it is recommended to use `guid` over `name`, as support for using `name` with this resource shall eventually be discontinued. Please see the note under `name` for more details.
        :param pulumi.Input[_builtins.str] name: The name of the application in New Relic.
        :param pulumi.Input[_builtins.str] tracer_type: Configures the type of tracer used. Valid values are `CROSS_APPLICATION_TRACER`, `DISTRIBUTED_TRACING`, `NONE`, `OPT_OUT`.
        :param pulumi.Input[Sequence[pulumi.Input['ApplicationSettingsTransactionTracerArgs']]] transaction_tracers: Configuration block for transaction tracer. Providing this block enables transaction tracing. The following arguments are supported:
        :param pulumi.Input[_builtins.bool] use_server_side_config: Enable or disable server side monitoring for the New Relic application.
        """
        if app_apdex_threshold is not None:
            pulumi.set(__self__, "app_apdex_threshold", app_apdex_threshold)
        if enable_real_user_monitoring is not None:
            pulumi.set(__self__, "enable_real_user_monitoring", enable_real_user_monitoring)
        if enable_slow_sql is not None:
            pulumi.set(__self__, "enable_slow_sql", enable_slow_sql)
        if enable_thread_profiler is not None:
            pulumi.set(__self__, "enable_thread_profiler", enable_thread_profiler)
        if end_user_apdex_threshold is not None:
            pulumi.set(__self__, "end_user_apdex_threshold", end_user_apdex_threshold)
        if error_collectors is not None:
            pulumi.set(__self__, "error_collectors", error_collectors)
        if guid is not None:
            pulumi.set(__self__, "guid", guid)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if tracer_type is not None:
            pulumi.set(__self__, "tracer_type", tracer_type)
        if transaction_tracers is not None:
            pulumi.set(__self__, "transaction_tracers", transaction_tracers)
        if use_server_side_config is not None:
            pulumi.set(__self__, "use_server_side_config", use_server_side_config)

    @_builtins.property
    @pulumi.getter(name="appApdexThreshold")
    def app_apdex_threshold(self) -> Optional[pulumi.Input[_builtins.float]]:
        """
        The acceptable response time limit (Apdex threshold) for the application.
        """
        return pulumi.get(self, "app_apdex_threshold")

    @app_apdex_threshold.setter
    def app_apdex_threshold(self, value: Optional[pulumi.Input[_builtins.float]]):
        pulumi.set(self, "app_apdex_threshold", value)

    @_builtins.property
    @pulumi.getter(name="enableRealUserMonitoring")
    def enable_real_user_monitoring(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Dummy field to support backward compatibility of previous version.should be removed with next major version.
        """
        return pulumi.get(self, "enable_real_user_monitoring")

    @enable_real_user_monitoring.setter
    def enable_real_user_monitoring(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enable_real_user_monitoring", value)

    @_builtins.property
    @pulumi.getter(name="enableSlowSql")
    def enable_slow_sql(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable or disable the collection of slowest database queries in your traces.
        """
        return pulumi.get(self, "enable_slow_sql")

    @enable_slow_sql.setter
    def enable_slow_sql(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enable_slow_sql", value)

    @_builtins.property
    @pulumi.getter(name="enableThreadProfiler")
    def enable_thread_profiler(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable or disable the collection of thread profiling data.
        """
        return pulumi.get(self, "enable_thread_profiler")

    @enable_thread_profiler.setter
    def enable_thread_profiler(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enable_thread_profiler", value)

    @_builtins.property
    @pulumi.getter(name="endUserApdexThreshold")
    def end_user_apdex_threshold(self) -> Optional[pulumi.Input[_builtins.float]]:
        """
        Dummy field to support backward compatibility of previous version.should be removed with next major version.
        """
        return pulumi.get(self, "end_user_apdex_threshold")

    @end_user_apdex_threshold.setter
    def end_user_apdex_threshold(self, value: Optional[pulumi.Input[_builtins.float]]):
        pulumi.set(self, "end_user_apdex_threshold", value)

    @_builtins.property
    @pulumi.getter(name="errorCollectors")
    def error_collectors(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationSettingsErrorCollectorArgs']]]]:
        """
        Configuration block for error collection. Including this block enables the error collector. The following arguments are supported:
        """
        return pulumi.get(self, "error_collectors")

    @error_collectors.setter
    def error_collectors(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationSettingsErrorCollectorArgs']]]]):
        pulumi.set(self, "error_collectors", value)

    @_builtins.property
    @pulumi.getter
    def guid(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The GUID of the application in New Relic APM.

        > **NOTE:** While the attribute `guid` is not mandatory at a schema level, it is recommended to use `guid` over `name`, as support for using `name` with this resource shall eventually be discontinued. Please see the note under `name` for more details.
        """
        return pulumi.get(self, "guid")

    @guid.setter
    def guid(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "guid", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the application in New Relic.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="tracerType")
    def tracer_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Configures the type of tracer used. Valid values are `CROSS_APPLICATION_TRACER`, `DISTRIBUTED_TRACING`, `NONE`, `OPT_OUT`.
        """
        return pulumi.get(self, "tracer_type")

    @tracer_type.setter
    def tracer_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tracer_type", value)

    @_builtins.property
    @pulumi.getter(name="transactionTracers")
    def transaction_tracers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationSettingsTransactionTracerArgs']]]]:
        """
        Configuration block for transaction tracer. Providing this block enables transaction tracing. The following arguments are supported:
        """
        return pulumi.get(self, "transaction_tracers")

    @transaction_tracers.setter
    def transaction_tracers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationSettingsTransactionTracerArgs']]]]):
        pulumi.set(self, "transaction_tracers", value)

    @_builtins.property
    @pulumi.getter(name="useServerSideConfig")
    def use_server_side_config(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable or disable server side monitoring for the New Relic application.
        """
        return pulumi.get(self, "use_server_side_config")

    @use_server_side_config.setter
    def use_server_side_config(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "use_server_side_config", value)


@pulumi.input_type
class _ApplicationSettingsState:
    def __init__(__self__, *,
                 app_apdex_threshold: Optional[pulumi.Input[_builtins.float]] = None,
                 enable_real_user_monitoring: Optional[pulumi.Input[_builtins.bool]] = None,
                 enable_slow_sql: Optional[pulumi.Input[_builtins.bool]] = None,
                 enable_thread_profiler: Optional[pulumi.Input[_builtins.bool]] = None,
                 end_user_apdex_threshold: Optional[pulumi.Input[_builtins.float]] = None,
                 error_collectors: Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationSettingsErrorCollectorArgs']]]] = None,
                 guid: Optional[pulumi.Input[_builtins.str]] = None,
                 is_imported: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 tracer_type: Optional[pulumi.Input[_builtins.str]] = None,
                 transaction_tracers: Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationSettingsTransactionTracerArgs']]]] = None,
                 use_server_side_config: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        Input properties used for looking up and filtering ApplicationSettings resources.
        :param pulumi.Input[_builtins.float] app_apdex_threshold: The acceptable response time limit (Apdex threshold) for the application.
        :param pulumi.Input[_builtins.bool] enable_real_user_monitoring: Dummy field to support backward compatibility of previous version.should be removed with next major version.
        :param pulumi.Input[_builtins.bool] enable_slow_sql: Enable or disable the collection of slowest database queries in your traces.
        :param pulumi.Input[_builtins.bool] enable_thread_profiler: Enable or disable the collection of thread profiling data.
        :param pulumi.Input[_builtins.float] end_user_apdex_threshold: Dummy field to support backward compatibility of previous version.should be removed with next major version.
        :param pulumi.Input[Sequence[pulumi.Input['ApplicationSettingsErrorCollectorArgs']]] error_collectors: Configuration block for error collection. Including this block enables the error collector. The following arguments are supported:
        :param pulumi.Input[_builtins.str] guid: The GUID of the application in New Relic APM.
               
               > **NOTE:** While the attribute `guid` is not mandatory at a schema level, it is recommended to use `guid` over `name`, as support for using `name` with this resource shall eventually be discontinued. Please see the note under `name` for more details.
        :param pulumi.Input[_builtins.str] name: The name of the application in New Relic.
        :param pulumi.Input[_builtins.str] tracer_type: Configures the type of tracer used. Valid values are `CROSS_APPLICATION_TRACER`, `DISTRIBUTED_TRACING`, `NONE`, `OPT_OUT`.
        :param pulumi.Input[Sequence[pulumi.Input['ApplicationSettingsTransactionTracerArgs']]] transaction_tracers: Configuration block for transaction tracer. Providing this block enables transaction tracing. The following arguments are supported:
        :param pulumi.Input[_builtins.bool] use_server_side_config: Enable or disable server side monitoring for the New Relic application.
        """
        if app_apdex_threshold is not None:
            pulumi.set(__self__, "app_apdex_threshold", app_apdex_threshold)
        if enable_real_user_monitoring is not None:
            pulumi.set(__self__, "enable_real_user_monitoring", enable_real_user_monitoring)
        if enable_slow_sql is not None:
            pulumi.set(__self__, "enable_slow_sql", enable_slow_sql)
        if enable_thread_profiler is not None:
            pulumi.set(__self__, "enable_thread_profiler", enable_thread_profiler)
        if end_user_apdex_threshold is not None:
            pulumi.set(__self__, "end_user_apdex_threshold", end_user_apdex_threshold)
        if error_collectors is not None:
            pulumi.set(__self__, "error_collectors", error_collectors)
        if guid is not None:
            pulumi.set(__self__, "guid", guid)
        if is_imported is not None:
            pulumi.set(__self__, "is_imported", is_imported)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if tracer_type is not None:
            pulumi.set(__self__, "tracer_type", tracer_type)
        if transaction_tracers is not None:
            pulumi.set(__self__, "transaction_tracers", transaction_tracers)
        if use_server_side_config is not None:
            pulumi.set(__self__, "use_server_side_config", use_server_side_config)

    @_builtins.property
    @pulumi.getter(name="appApdexThreshold")
    def app_apdex_threshold(self) -> Optional[pulumi.Input[_builtins.float]]:
        """
        The acceptable response time limit (Apdex threshold) for the application.
        """
        return pulumi.get(self, "app_apdex_threshold")

    @app_apdex_threshold.setter
    def app_apdex_threshold(self, value: Optional[pulumi.Input[_builtins.float]]):
        pulumi.set(self, "app_apdex_threshold", value)

    @_builtins.property
    @pulumi.getter(name="enableRealUserMonitoring")
    def enable_real_user_monitoring(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Dummy field to support backward compatibility of previous version.should be removed with next major version.
        """
        return pulumi.get(self, "enable_real_user_monitoring")

    @enable_real_user_monitoring.setter
    def enable_real_user_monitoring(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enable_real_user_monitoring", value)

    @_builtins.property
    @pulumi.getter(name="enableSlowSql")
    def enable_slow_sql(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable or disable the collection of slowest database queries in your traces.
        """
        return pulumi.get(self, "enable_slow_sql")

    @enable_slow_sql.setter
    def enable_slow_sql(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enable_slow_sql", value)

    @_builtins.property
    @pulumi.getter(name="enableThreadProfiler")
    def enable_thread_profiler(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable or disable the collection of thread profiling data.
        """
        return pulumi.get(self, "enable_thread_profiler")

    @enable_thread_profiler.setter
    def enable_thread_profiler(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enable_thread_profiler", value)

    @_builtins.property
    @pulumi.getter(name="endUserApdexThreshold")
    def end_user_apdex_threshold(self) -> Optional[pulumi.Input[_builtins.float]]:
        """
        Dummy field to support backward compatibility of previous version.should be removed with next major version.
        """
        return pulumi.get(self, "end_user_apdex_threshold")

    @end_user_apdex_threshold.setter
    def end_user_apdex_threshold(self, value: Optional[pulumi.Input[_builtins.float]]):
        pulumi.set(self, "end_user_apdex_threshold", value)

    @_builtins.property
    @pulumi.getter(name="errorCollectors")
    def error_collectors(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationSettingsErrorCollectorArgs']]]]:
        """
        Configuration block for error collection. Including this block enables the error collector. The following arguments are supported:
        """
        return pulumi.get(self, "error_collectors")

    @error_collectors.setter
    def error_collectors(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationSettingsErrorCollectorArgs']]]]):
        pulumi.set(self, "error_collectors", value)

    @_builtins.property
    @pulumi.getter
    def guid(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The GUID of the application in New Relic APM.

        > **NOTE:** While the attribute `guid` is not mandatory at a schema level, it is recommended to use `guid` over `name`, as support for using `name` with this resource shall eventually be discontinued. Please see the note under `name` for more details.
        """
        return pulumi.get(self, "guid")

    @guid.setter
    def guid(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "guid", value)

    @_builtins.property
    @pulumi.getter(name="isImported")
    def is_imported(self) -> Optional[pulumi.Input[_builtins.bool]]:
        return pulumi.get(self, "is_imported")

    @is_imported.setter
    def is_imported(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_imported", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the application in New Relic.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="tracerType")
    def tracer_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Configures the type of tracer used. Valid values are `CROSS_APPLICATION_TRACER`, `DISTRIBUTED_TRACING`, `NONE`, `OPT_OUT`.
        """
        return pulumi.get(self, "tracer_type")

    @tracer_type.setter
    def tracer_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "tracer_type", value)

    @_builtins.property
    @pulumi.getter(name="transactionTracers")
    def transaction_tracers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationSettingsTransactionTracerArgs']]]]:
        """
        Configuration block for transaction tracer. Providing this block enables transaction tracing. The following arguments are supported:
        """
        return pulumi.get(self, "transaction_tracers")

    @transaction_tracers.setter
    def transaction_tracers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ApplicationSettingsTransactionTracerArgs']]]]):
        pulumi.set(self, "transaction_tracers", value)

    @_builtins.property
    @pulumi.getter(name="useServerSideConfig")
    def use_server_side_config(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable or disable server side monitoring for the New Relic application.
        """
        return pulumi.get(self, "use_server_side_config")

    @use_server_side_config.setter
    def use_server_side_config(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "use_server_side_config", value)


@pulumi.type_token("newrelic:plugins/applicationSettings:ApplicationSettings")
class ApplicationSettings(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_apdex_threshold: Optional[pulumi.Input[_builtins.float]] = None,
                 enable_real_user_monitoring: Optional[pulumi.Input[_builtins.bool]] = None,
                 enable_slow_sql: Optional[pulumi.Input[_builtins.bool]] = None,
                 enable_thread_profiler: Optional[pulumi.Input[_builtins.bool]] = None,
                 end_user_apdex_threshold: Optional[pulumi.Input[_builtins.float]] = None,
                 error_collectors: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ApplicationSettingsErrorCollectorArgs', 'ApplicationSettingsErrorCollectorArgsDict']]]]] = None,
                 guid: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 tracer_type: Optional[pulumi.Input[_builtins.str]] = None,
                 transaction_tracers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ApplicationSettingsTransactionTracerArgs', 'ApplicationSettingsTransactionTracerArgsDict']]]]] = None,
                 use_server_side_config: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        """
        ## Import

        Applications can be imported using notation `application_guid`, e.g.

        ```sh
        $ pulumi import newrelic:plugins/applicationSettings:ApplicationSettings main Mzk1NzUyNHQVRJNTxBUE18QVBQTElDc4ODU1MzYx
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.float] app_apdex_threshold: The acceptable response time limit (Apdex threshold) for the application.
        :param pulumi.Input[_builtins.bool] enable_real_user_monitoring: Dummy field to support backward compatibility of previous version.should be removed with next major version.
        :param pulumi.Input[_builtins.bool] enable_slow_sql: Enable or disable the collection of slowest database queries in your traces.
        :param pulumi.Input[_builtins.bool] enable_thread_profiler: Enable or disable the collection of thread profiling data.
        :param pulumi.Input[_builtins.float] end_user_apdex_threshold: Dummy field to support backward compatibility of previous version.should be removed with next major version.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ApplicationSettingsErrorCollectorArgs', 'ApplicationSettingsErrorCollectorArgsDict']]]] error_collectors: Configuration block for error collection. Including this block enables the error collector. The following arguments are supported:
        :param pulumi.Input[_builtins.str] guid: The GUID of the application in New Relic APM.
               
               > **NOTE:** While the attribute `guid` is not mandatory at a schema level, it is recommended to use `guid` over `name`, as support for using `name` with this resource shall eventually be discontinued. Please see the note under `name` for more details.
        :param pulumi.Input[_builtins.str] name: The name of the application in New Relic.
        :param pulumi.Input[_builtins.str] tracer_type: Configures the type of tracer used. Valid values are `CROSS_APPLICATION_TRACER`, `DISTRIBUTED_TRACING`, `NONE`, `OPT_OUT`.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ApplicationSettingsTransactionTracerArgs', 'ApplicationSettingsTransactionTracerArgsDict']]]] transaction_tracers: Configuration block for transaction tracer. Providing this block enables transaction tracing. The following arguments are supported:
        :param pulumi.Input[_builtins.bool] use_server_side_config: Enable or disable server side monitoring for the New Relic application.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ApplicationSettingsArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        Applications can be imported using notation `application_guid`, e.g.

        ```sh
        $ pulumi import newrelic:plugins/applicationSettings:ApplicationSettings main Mzk1NzUyNHQVRJNTxBUE18QVBQTElDc4ODU1MzYx
        ```

        :param str resource_name: The name of the resource.
        :param ApplicationSettingsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ApplicationSettingsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_apdex_threshold: Optional[pulumi.Input[_builtins.float]] = None,
                 enable_real_user_monitoring: Optional[pulumi.Input[_builtins.bool]] = None,
                 enable_slow_sql: Optional[pulumi.Input[_builtins.bool]] = None,
                 enable_thread_profiler: Optional[pulumi.Input[_builtins.bool]] = None,
                 end_user_apdex_threshold: Optional[pulumi.Input[_builtins.float]] = None,
                 error_collectors: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ApplicationSettingsErrorCollectorArgs', 'ApplicationSettingsErrorCollectorArgsDict']]]]] = None,
                 guid: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 tracer_type: Optional[pulumi.Input[_builtins.str]] = None,
                 transaction_tracers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ApplicationSettingsTransactionTracerArgs', 'ApplicationSettingsTransactionTracerArgsDict']]]]] = None,
                 use_server_side_config: Optional[pulumi.Input[_builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ApplicationSettingsArgs.__new__(ApplicationSettingsArgs)

            __props__.__dict__["app_apdex_threshold"] = app_apdex_threshold
            __props__.__dict__["enable_real_user_monitoring"] = enable_real_user_monitoring
            __props__.__dict__["enable_slow_sql"] = enable_slow_sql
            __props__.__dict__["enable_thread_profiler"] = enable_thread_profiler
            __props__.__dict__["end_user_apdex_threshold"] = end_user_apdex_threshold
            __props__.__dict__["error_collectors"] = error_collectors
            __props__.__dict__["guid"] = guid
            __props__.__dict__["name"] = name
            __props__.__dict__["tracer_type"] = tracer_type
            __props__.__dict__["transaction_tracers"] = transaction_tracers
            __props__.__dict__["use_server_side_config"] = use_server_side_config
            __props__.__dict__["is_imported"] = None
        super(ApplicationSettings, __self__).__init__(
            'newrelic:plugins/applicationSettings:ApplicationSettings',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            app_apdex_threshold: Optional[pulumi.Input[_builtins.float]] = None,
            enable_real_user_monitoring: Optional[pulumi.Input[_builtins.bool]] = None,
            enable_slow_sql: Optional[pulumi.Input[_builtins.bool]] = None,
            enable_thread_profiler: Optional[pulumi.Input[_builtins.bool]] = None,
            end_user_apdex_threshold: Optional[pulumi.Input[_builtins.float]] = None,
            error_collectors: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ApplicationSettingsErrorCollectorArgs', 'ApplicationSettingsErrorCollectorArgsDict']]]]] = None,
            guid: Optional[pulumi.Input[_builtins.str]] = None,
            is_imported: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            tracer_type: Optional[pulumi.Input[_builtins.str]] = None,
            transaction_tracers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ApplicationSettingsTransactionTracerArgs', 'ApplicationSettingsTransactionTracerArgsDict']]]]] = None,
            use_server_side_config: Optional[pulumi.Input[_builtins.bool]] = None) -> 'ApplicationSettings':
        """
        Get an existing ApplicationSettings resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.float] app_apdex_threshold: The acceptable response time limit (Apdex threshold) for the application.
        :param pulumi.Input[_builtins.bool] enable_real_user_monitoring: Dummy field to support backward compatibility of previous version.should be removed with next major version.
        :param pulumi.Input[_builtins.bool] enable_slow_sql: Enable or disable the collection of slowest database queries in your traces.
        :param pulumi.Input[_builtins.bool] enable_thread_profiler: Enable or disable the collection of thread profiling data.
        :param pulumi.Input[_builtins.float] end_user_apdex_threshold: Dummy field to support backward compatibility of previous version.should be removed with next major version.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ApplicationSettingsErrorCollectorArgs', 'ApplicationSettingsErrorCollectorArgsDict']]]] error_collectors: Configuration block for error collection. Including this block enables the error collector. The following arguments are supported:
        :param pulumi.Input[_builtins.str] guid: The GUID of the application in New Relic APM.
               
               > **NOTE:** While the attribute `guid` is not mandatory at a schema level, it is recommended to use `guid` over `name`, as support for using `name` with this resource shall eventually be discontinued. Please see the note under `name` for more details.
        :param pulumi.Input[_builtins.str] name: The name of the application in New Relic.
        :param pulumi.Input[_builtins.str] tracer_type: Configures the type of tracer used. Valid values are `CROSS_APPLICATION_TRACER`, `DISTRIBUTED_TRACING`, `NONE`, `OPT_OUT`.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ApplicationSettingsTransactionTracerArgs', 'ApplicationSettingsTransactionTracerArgsDict']]]] transaction_tracers: Configuration block for transaction tracer. Providing this block enables transaction tracing. The following arguments are supported:
        :param pulumi.Input[_builtins.bool] use_server_side_config: Enable or disable server side monitoring for the New Relic application.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ApplicationSettingsState.__new__(_ApplicationSettingsState)

        __props__.__dict__["app_apdex_threshold"] = app_apdex_threshold
        __props__.__dict__["enable_real_user_monitoring"] = enable_real_user_monitoring
        __props__.__dict__["enable_slow_sql"] = enable_slow_sql
        __props__.__dict__["enable_thread_profiler"] = enable_thread_profiler
        __props__.__dict__["end_user_apdex_threshold"] = end_user_apdex_threshold
        __props__.__dict__["error_collectors"] = error_collectors
        __props__.__dict__["guid"] = guid
        __props__.__dict__["is_imported"] = is_imported
        __props__.__dict__["name"] = name
        __props__.__dict__["tracer_type"] = tracer_type
        __props__.__dict__["transaction_tracers"] = transaction_tracers
        __props__.__dict__["use_server_side_config"] = use_server_side_config
        return ApplicationSettings(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="appApdexThreshold")
    def app_apdex_threshold(self) -> pulumi.Output[Optional[_builtins.float]]:
        """
        The acceptable response time limit (Apdex threshold) for the application.
        """
        return pulumi.get(self, "app_apdex_threshold")

    @_builtins.property
    @pulumi.getter(name="enableRealUserMonitoring")
    def enable_real_user_monitoring(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Dummy field to support backward compatibility of previous version.should be removed with next major version.
        """
        return pulumi.get(self, "enable_real_user_monitoring")

    @_builtins.property
    @pulumi.getter(name="enableSlowSql")
    def enable_slow_sql(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Enable or disable the collection of slowest database queries in your traces.
        """
        return pulumi.get(self, "enable_slow_sql")

    @_builtins.property
    @pulumi.getter(name="enableThreadProfiler")
    def enable_thread_profiler(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Enable or disable the collection of thread profiling data.
        """
        return pulumi.get(self, "enable_thread_profiler")

    @_builtins.property
    @pulumi.getter(name="endUserApdexThreshold")
    def end_user_apdex_threshold(self) -> pulumi.Output[Optional[_builtins.float]]:
        """
        Dummy field to support backward compatibility of previous version.should be removed with next major version.
        """
        return pulumi.get(self, "end_user_apdex_threshold")

    @_builtins.property
    @pulumi.getter(name="errorCollectors")
    def error_collectors(self) -> pulumi.Output[Optional[Sequence['outputs.ApplicationSettingsErrorCollector']]]:
        """
        Configuration block for error collection. Including this block enables the error collector. The following arguments are supported:
        """
        return pulumi.get(self, "error_collectors")

    @_builtins.property
    @pulumi.getter
    def guid(self) -> pulumi.Output[_builtins.str]:
        """
        The GUID of the application in New Relic APM.

        > **NOTE:** While the attribute `guid` is not mandatory at a schema level, it is recommended to use `guid` over `name`, as support for using `name` with this resource shall eventually be discontinued. Please see the note under `name` for more details.
        """
        return pulumi.get(self, "guid")

    @_builtins.property
    @pulumi.getter(name="isImported")
    def is_imported(self) -> pulumi.Output[_builtins.bool]:
        return pulumi.get(self, "is_imported")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the application in New Relic.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="tracerType")
    def tracer_type(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Configures the type of tracer used. Valid values are `CROSS_APPLICATION_TRACER`, `DISTRIBUTED_TRACING`, `NONE`, `OPT_OUT`.
        """
        return pulumi.get(self, "tracer_type")

    @_builtins.property
    @pulumi.getter(name="transactionTracers")
    def transaction_tracers(self) -> pulumi.Output[Optional[Sequence['outputs.ApplicationSettingsTransactionTracer']]]:
        """
        Configuration block for transaction tracer. Providing this block enables transaction tracing. The following arguments are supported:
        """
        return pulumi.get(self, "transaction_tracers")

    @_builtins.property
    @pulumi.getter(name="useServerSideConfig")
    def use_server_side_config(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Enable or disable server side monitoring for the New Relic application.
        """
        return pulumi.get(self, "use_server_side_config")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetAlertChannelResult',
    'AwaitableGetAlertChannelResult',
    'get_alert_channel',
    'get_alert_channel_output',
]

@pulumi.output_type
class GetAlertChannelResult:
    """
    A collection of values returned by getAlertChannel.
    """
    def __init__(__self__, account_id=None, config=None, id=None, name=None, policy_ids=None, type=None):
        if account_id and not isinstance(account_id, str):
            raise TypeError("Expected argument 'account_id' to be a str")
        pulumi.set(__self__, "account_id", account_id)
        if config and not isinstance(config, dict):
            raise TypeError("Expected argument 'config' to be a dict")
        pulumi.set(__self__, "config", config)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if policy_ids and not isinstance(policy_ids, list):
            raise TypeError("Expected argument 'policy_ids' to be a list")
        pulumi.set(__self__, "policy_ids", policy_ids)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> _builtins.str:
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter
    def config(self) -> 'outputs.GetAlertChannelConfigResult':
        """
        Alert channel configuration.
        """
        return pulumi.get(self, "config")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="policyIds")
    def policy_ids(self) -> Sequence[_builtins.str]:
        """
        A list of policy IDs associated with the alert channel.
        """
        return pulumi.get(self, "policy_ids")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        Alert channel type, either: `email`, `opsgenie`, `pagerduty`, `slack`, `victorops`, or `webhook`.
        """
        return pulumi.get(self, "type")


class AwaitableGetAlertChannelResult(GetAlertChannelResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAlertChannelResult(
            account_id=self.account_id,
            config=self.config,
            id=self.id,
            name=self.name,
            policy_ids=self.policy_ids,
            type=self.type)


def get_alert_channel(account_id: Optional[_builtins.str] = None,
                      name: Optional[_builtins.str] = None,
                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAlertChannelResult:
    """
    Use this data source to get information about a specific alert channel in New Relic that already exists.

    > **WARNING:** The `AlertChannel` data source is deprecated and will be removed in the next major release.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_newrelic as newrelic

    # Data source
    foo = newrelic.get_alert_channel(name="foo@example.com")
    # Resource
    foo_alert_policy = newrelic.AlertPolicy("foo", name="foo")
    # Using the data source and resource together
    foo_alert_policy_channel = newrelic.AlertPolicyChannel("foo",
        policy_id=foo_alert_policy.id,
        channel_id=foo.id)
    ```


    :param _builtins.str account_id: The New Relic account ID to operate on.  This allows you to override the `account_id` attribute set on the provider. Defaults to the environment variable `NEW_RELIC_ACCOUNT_ID`.
    :param _builtins.str name: The name of the alert channel in New Relic.
    """
    __args__ = dict()
    __args__['accountId'] = account_id
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('newrelic:index/getAlertChannel:getAlertChannel', __args__, opts=opts, typ=GetAlertChannelResult).value

    return AwaitableGetAlertChannelResult(
        account_id=pulumi.get(__ret__, 'account_id'),
        config=pulumi.get(__ret__, 'config'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        policy_ids=pulumi.get(__ret__, 'policy_ids'),
        type=pulumi.get(__ret__, 'type'))
def get_alert_channel_output(account_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                             name: Optional[pulumi.Input[_builtins.str]] = None,
                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAlertChannelResult]:
    """
    Use this data source to get information about a specific alert channel in New Relic that already exists.

    > **WARNING:** The `AlertChannel` data source is deprecated and will be removed in the next major release.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_newrelic as newrelic

    # Data source
    foo = newrelic.get_alert_channel(name="foo@example.com")
    # Resource
    foo_alert_policy = newrelic.AlertPolicy("foo", name="foo")
    # Using the data source and resource together
    foo_alert_policy_channel = newrelic.AlertPolicyChannel("foo",
        policy_id=foo_alert_policy.id,
        channel_id=foo.id)
    ```


    :param _builtins.str account_id: The New Relic account ID to operate on.  This allows you to override the `account_id` attribute set on the provider. Defaults to the environment variable `NEW_RELIC_ACCOUNT_ID`.
    :param _builtins.str name: The name of the alert channel in New Relic.
    """
    __args__ = dict()
    __args__['accountId'] = account_id
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('newrelic:index/getAlertChannel:getAlertChannel', __args__, opts=opts, typ=GetAlertChannelResult)
    return __ret__.apply(lambda __response__: GetAlertChannelResult(
        account_id=pulumi.get(__response__, 'account_id'),
        config=pulumi.get(__response__, 'config'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        policy_ids=pulumi.get(__response__, 'policy_ids'),
        type=pulumi.get(__response__, 'type')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
from . import _utilities
import typing
# Export this package's modules as members:
from .account_management import *
from .alert_channel import *
from .alert_condition import *
from .alert_muting_rule import *
from .alert_policy import *
from .alert_policy_channel import *
from .api_access_key import *
from .browser_application import *
from .data_partition_rule import *
from .entity_tags import *
from .events_to_metrics_rule import *
from .get_account import *
from .get_alert_channel import *
from .get_alert_policy import *
from .get_application import *
from .get_authentication_domain import *
from .get_cloud_account import *
from .get_entity import *
from .get_group import *
from .get_key_transaction import *
from .get_notification_destination import *
from .get_obfuscation_expression import *
from .get_service_level_alert_helper import *
from .get_test_grok_pattern import *
from .get_user import *
from .group import *
from .infra_alert_condition import *
from .key_transaction import *
from .log_parsing_rule import *
from .monitor_downtime import *
from .notification_channel import *
from .notification_destination import *
from .nrql_alert_condition import *
from .nrql_drop_rule import *
from .obfuscation_expression import *
from .obfuscation_rule import *
from .one_dashboard import *
from .one_dashboard_json import *
from .one_dashboard_raw import *
from .pipeline_cloud_rule import *
from .provider import *
from .service_level import *
from .user import *
from .workflow import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_newrelic.cloud as __cloud
    cloud = __cloud
    import pulumi_newrelic.config as __config
    config = __config
    import pulumi_newrelic.insights as __insights
    insights = __insights
    import pulumi_newrelic.plugins as __plugins
    plugins = __plugins
    import pulumi_newrelic.synthetics as __synthetics
    synthetics = __synthetics
else:
    cloud = _utilities.lazy_import('pulumi_newrelic.cloud')
    config = _utilities.lazy_import('pulumi_newrelic.config')
    insights = _utilities.lazy_import('pulumi_newrelic.insights')
    plugins = _utilities.lazy_import('pulumi_newrelic.plugins')
    synthetics = _utilities.lazy_import('pulumi_newrelic.synthetics')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "newrelic",
  "mod": "cloud/awsGovcloudIntegrations",
  "fqn": "pulumi_newrelic.cloud",
  "classes": {
   "newrelic:cloud/awsGovcloudIntegrations:AwsGovcloudIntegrations": "AwsGovcloudIntegrations"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "cloud/awsGovcloudLinkAccount",
  "fqn": "pulumi_newrelic.cloud",
  "classes": {
   "newrelic:cloud/awsGovcloudLinkAccount:AwsGovcloudLinkAccount": "AwsGovcloudLinkAccount"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "cloud/awsIntegrations",
  "fqn": "pulumi_newrelic.cloud",
  "classes": {
   "newrelic:cloud/awsIntegrations:AwsIntegrations": "AwsIntegrations"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "cloud/awsLinkAccount",
  "fqn": "pulumi_newrelic.cloud",
  "classes": {
   "newrelic:cloud/awsLinkAccount:AwsLinkAccount": "AwsLinkAccount"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "cloud/azureIntegrations",
  "fqn": "pulumi_newrelic.cloud",
  "classes": {
   "newrelic:cloud/azureIntegrations:AzureIntegrations": "AzureIntegrations"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "cloud/azureLinkAccount",
  "fqn": "pulumi_newrelic.cloud",
  "classes": {
   "newrelic:cloud/azureLinkAccount:AzureLinkAccount": "AzureLinkAccount"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "cloud/gcpIntegrations",
  "fqn": "pulumi_newrelic.cloud",
  "classes": {
   "newrelic:cloud/gcpIntegrations:GcpIntegrations": "GcpIntegrations"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "cloud/gcpLinkAccount",
  "fqn": "pulumi_newrelic.cloud",
  "classes": {
   "newrelic:cloud/gcpLinkAccount:GcpLinkAccount": "GcpLinkAccount"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "cloud/ociLinkAccount",
  "fqn": "pulumi_newrelic.cloud",
  "classes": {
   "newrelic:cloud/ociLinkAccount:OciLinkAccount": "OciLinkAccount"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "index/accountManagement",
  "fqn": "pulumi_newrelic",
  "classes": {
   "newrelic:index/accountManagement:AccountManagement": "AccountManagement"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "index/alertChannel",
  "fqn": "pulumi_newrelic",
  "classes": {
   "newrelic:index/alertChannel:AlertChannel": "AlertChannel"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "index/alertCondition",
  "fqn": "pulumi_newrelic",
  "classes": {
   "newrelic:index/alertCondition:AlertCondition": "AlertCondition"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "index/alertMutingRule",
  "fqn": "pulumi_newrelic",
  "classes": {
   "newrelic:index/alertMutingRule:AlertMutingRule": "AlertMutingRule"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "index/alertPolicy",
  "fqn": "pulumi_newrelic",
  "classes": {
   "newrelic:index/alertPolicy:AlertPolicy": "AlertPolicy"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "index/alertPolicyChannel",
  "fqn": "pulumi_newrelic",
  "classes": {
   "newrelic:index/alertPolicyChannel:AlertPolicyChannel": "AlertPolicyChannel"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "index/apiAccessKey",
  "fqn": "pulumi_newrelic",
  "classes": {
   "newrelic:index/apiAccessKey:ApiAccessKey": "ApiAccessKey"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "index/browserApplication",
  "fqn": "pulumi_newrelic",
  "classes": {
   "newrelic:index/browserApplication:BrowserApplication": "BrowserApplication"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "index/dataPartitionRule",
  "fqn": "pulumi_newrelic",
  "classes": {
   "newrelic:index/dataPartitionRule:DataPartitionRule": "DataPartitionRule"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "index/entityTags",
  "fqn": "pulumi_newrelic",
  "classes": {
   "newrelic:index/entityTags:EntityTags": "EntityTags"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "index/eventsToMetricsRule",
  "fqn": "pulumi_newrelic",
  "classes": {
   "newrelic:index/eventsToMetricsRule:EventsToMetricsRule": "EventsToMetricsRule"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "index/group",
  "fqn": "pulumi_newrelic",
  "classes": {
   "newrelic:index/group:Group": "Group"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "index/infraAlertCondition",
  "fqn": "pulumi_newrelic",
  "classes": {
   "newrelic:index/infraAlertCondition:InfraAlertCondition": "InfraAlertCondition"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "index/keyTransaction",
  "fqn": "pulumi_newrelic",
  "classes": {
   "newrelic:index/keyTransaction:KeyTransaction": "KeyTransaction"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "index/logParsingRule",
  "fqn": "pulumi_newrelic",
  "classes": {
   "newrelic:index/logParsingRule:LogParsingRule": "LogParsingRule"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "index/monitorDowntime",
  "fqn": "pulumi_newrelic",
  "classes": {
   "newrelic:index/monitorDowntime:MonitorDowntime": "MonitorDowntime"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "index/notificationChannel",
  "fqn": "pulumi_newrelic",
  "classes": {
   "newrelic:index/notificationChannel:NotificationChannel": "NotificationChannel"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "index/notificationDestination",
  "fqn": "pulumi_newrelic",
  "classes": {
   "newrelic:index/notificationDestination:NotificationDestination": "NotificationDestination"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "index/nrqlAlertCondition",
  "fqn": "pulumi_newrelic",
  "classes": {
   "newrelic:index/nrqlAlertCondition:NrqlAlertCondition": "NrqlAlertCondition"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "index/nrqlDropRule",
  "fqn": "pulumi_newrelic",
  "classes": {
   "newrelic:index/nrqlDropRule:NrqlDropRule": "NrqlDropRule"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "index/obfuscationExpression",
  "fqn": "pulumi_newrelic",
  "classes": {
   "newrelic:index/obfuscationExpression:ObfuscationExpression": "ObfuscationExpression"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "index/obfuscationRule",
  "fqn": "pulumi_newrelic",
  "classes": {
   "newrelic:index/obfuscationRule:ObfuscationRule": "ObfuscationRule"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "index/oneDashboard",
  "fqn": "pulumi_newrelic",
  "classes": {
   "newrelic:index/oneDashboard:OneDashboard": "OneDashboard"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "index/oneDashboardJson",
  "fqn": "pulumi_newrelic",
  "classes": {
   "newrelic:index/oneDashboardJson:OneDashboardJson": "OneDashboardJson"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "index/oneDashboardRaw",
  "fqn": "pulumi_newrelic",
  "classes": {
   "newrelic:index/oneDashboardRaw:OneDashboardRaw": "OneDashboardRaw"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "index/pipelineCloudRule",
  "fqn": "pulumi_newrelic",
  "classes": {
   "newrelic:index/pipelineCloudRule:PipelineCloudRule": "PipelineCloudRule"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "index/serviceLevel",
  "fqn": "pulumi_newrelic",
  "classes": {
   "newrelic:index/serviceLevel:ServiceLevel": "ServiceLevel"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "index/user",
  "fqn": "pulumi_newrelic",
  "classes": {
   "newrelic:index/user:User": "User"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "index/workflow",
  "fqn": "pulumi_newrelic",
  "classes": {
   "newrelic:index/workflow:Workflow": "Workflow"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "insights/event",
  "fqn": "pulumi_newrelic.insights",
  "classes": {
   "newrelic:insights/event:Event": "Event"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "plugins/applicationSettings",
  "fqn": "pulumi_newrelic.plugins",
  "classes": {
   "newrelic:plugins/applicationSettings:ApplicationSettings": "ApplicationSettings"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "plugins/workload",
  "fqn": "pulumi_newrelic.plugins",
  "classes": {
   "newrelic:plugins/workload:Workload": "Workload"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "synthetics/alertCondition",
  "fqn": "pulumi_newrelic.synthetics",
  "classes": {
   "newrelic:synthetics/alertCondition:AlertCondition": "AlertCondition"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "synthetics/brokenLinksMonitor",
  "fqn": "pulumi_newrelic.synthetics",
  "classes": {
   "newrelic:synthetics/brokenLinksMonitor:BrokenLinksMonitor": "BrokenLinksMonitor"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "synthetics/certCheckMonitor",
  "fqn": "pulumi_newrelic.synthetics",
  "classes": {
   "newrelic:synthetics/certCheckMonitor:CertCheckMonitor": "CertCheckMonitor"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "synthetics/monitor",
  "fqn": "pulumi_newrelic.synthetics",
  "classes": {
   "newrelic:synthetics/monitor:Monitor": "Monitor"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "synthetics/multiLocationAlertCondition",
  "fqn": "pulumi_newrelic.synthetics",
  "classes": {
   "newrelic:synthetics/multiLocationAlertCondition:MultiLocationAlertCondition": "MultiLocationAlertCondition"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "synthetics/privateLocation",
  "fqn": "pulumi_newrelic.synthetics",
  "classes": {
   "newrelic:synthetics/privateLocation:PrivateLocation": "PrivateLocation"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "synthetics/scriptMonitor",
  "fqn": "pulumi_newrelic.synthetics",
  "classes": {
   "newrelic:synthetics/scriptMonitor:ScriptMonitor": "ScriptMonitor"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "synthetics/secureCredential",
  "fqn": "pulumi_newrelic.synthetics",
  "classes": {
   "newrelic:synthetics/secureCredential:SecureCredential": "SecureCredential"
  }
 },
 {
  "pkg": "newrelic",
  "mod": "synthetics/stepMonitor",
  "fqn": "pulumi_newrelic.synthetics",
  "classes": {
   "newrelic:synthetics/stepMonitor:StepMonitor": "StepMonitor"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "newrelic",
  "token": "pulumi:providers:newrelic",
  "fqn": "pulumi_newrelic",
  "class": "Provider"
 }
]
"""
)



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ObfuscationRuleArgs', 'ObfuscationRule']

@pulumi.input_type
class ObfuscationRuleArgs:
    def __init__(__self__, *,
                 actions: pulumi.Input[Sequence[pulumi.Input['ObfuscationRuleActionArgs']]],
                 enabled: pulumi.Input[_builtins.bool],
                 filter: pulumi.Input[_builtins.str],
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a ObfuscationRule resource.
        :param pulumi.Input[Sequence[pulumi.Input['ObfuscationRuleActionArgs']]] actions: Actions for the rule. The actions will be applied in the order specified by this list.
        :param pulumi.Input[_builtins.bool] enabled: Whether the rule should be applied or not to incoming data.
        :param pulumi.Input[_builtins.str] filter: NRQL for determining whether a given log record should have obfuscation actions applied.
        :param pulumi.Input[_builtins.str] account_id: The account id associated with the obfuscation rule.
        :param pulumi.Input[_builtins.str] description: Description of rule.
        :param pulumi.Input[_builtins.str] name: Name of rule.
        """
        pulumi.set(__self__, "actions", actions)
        pulumi.set(__self__, "enabled", enabled)
        pulumi.set(__self__, "filter", filter)
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def actions(self) -> pulumi.Input[Sequence[pulumi.Input['ObfuscationRuleActionArgs']]]:
        """
        Actions for the rule. The actions will be applied in the order specified by this list.
        """
        return pulumi.get(self, "actions")

    @actions.setter
    def actions(self, value: pulumi.Input[Sequence[pulumi.Input['ObfuscationRuleActionArgs']]]):
        pulumi.set(self, "actions", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> pulumi.Input[_builtins.bool]:
        """
        Whether the rule should be applied or not to incoming data.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: pulumi.Input[_builtins.bool]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter
    def filter(self) -> pulumi.Input[_builtins.str]:
        """
        NRQL for determining whether a given log record should have obfuscation actions applied.
        """
        return pulumi.get(self, "filter")

    @filter.setter
    def filter(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "filter", value)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The account id associated with the obfuscation rule.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of rule.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of rule.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _ObfuscationRuleState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 actions: Optional[pulumi.Input[Sequence[pulumi.Input['ObfuscationRuleActionArgs']]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 filter: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering ObfuscationRule resources.
        :param pulumi.Input[_builtins.str] account_id: The account id associated with the obfuscation rule.
        :param pulumi.Input[Sequence[pulumi.Input['ObfuscationRuleActionArgs']]] actions: Actions for the rule. The actions will be applied in the order specified by this list.
        :param pulumi.Input[_builtins.str] description: Description of rule.
        :param pulumi.Input[_builtins.bool] enabled: Whether the rule should be applied or not to incoming data.
        :param pulumi.Input[_builtins.str] filter: NRQL for determining whether a given log record should have obfuscation actions applied.
        :param pulumi.Input[_builtins.str] name: Name of rule.
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if actions is not None:
            pulumi.set(__self__, "actions", actions)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if filter is not None:
            pulumi.set(__self__, "filter", filter)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The account id associated with the obfuscation rule.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter
    def actions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ObfuscationRuleActionArgs']]]]:
        """
        Actions for the rule. The actions will be applied in the order specified by this list.
        """
        return pulumi.get(self, "actions")

    @actions.setter
    def actions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ObfuscationRuleActionArgs']]]]):
        pulumi.set(self, "actions", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of rule.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the rule should be applied or not to incoming data.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter
    def filter(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        NRQL for determining whether a given log record should have obfuscation actions applied.
        """
        return pulumi.get(self, "filter")

    @filter.setter
    def filter(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "filter", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of rule.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.type_token("newrelic:index/obfuscationRule:ObfuscationRule")
class ObfuscationRule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 actions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ObfuscationRuleActionArgs', 'ObfuscationRuleActionArgsDict']]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 filter: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Use this resource to create, update and delete New Relic Obfuscation Rule.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        bar = newrelic.ObfuscationExpression("bar",
            name="expressionName",
            description="description of the expression",
            regex="(^http)")
        foo = newrelic.ObfuscationRule("foo",
            name="ruleName",
            description="description of the rule",
            filter="hostStatus=running",
            enabled=True,
            actions=[{
                "attributes": ["message"],
                "expression_id": bar.id,
                "method": "MASK",
            }])
        ```

        ## Import

        New Relic obfuscation rule can be imported using the rule ID, e.g.

        bash

        ```sh
        $ pulumi import newrelic:index/obfuscationRule:ObfuscationRule foo 34567
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: The account id associated with the obfuscation rule.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ObfuscationRuleActionArgs', 'ObfuscationRuleActionArgsDict']]]] actions: Actions for the rule. The actions will be applied in the order specified by this list.
        :param pulumi.Input[_builtins.str] description: Description of rule.
        :param pulumi.Input[_builtins.bool] enabled: Whether the rule should be applied or not to incoming data.
        :param pulumi.Input[_builtins.str] filter: NRQL for determining whether a given log record should have obfuscation actions applied.
        :param pulumi.Input[_builtins.str] name: Name of rule.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ObfuscationRuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Use this resource to create, update and delete New Relic Obfuscation Rule.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        bar = newrelic.ObfuscationExpression("bar",
            name="expressionName",
            description="description of the expression",
            regex="(^http)")
        foo = newrelic.ObfuscationRule("foo",
            name="ruleName",
            description="description of the rule",
            filter="hostStatus=running",
            enabled=True,
            actions=[{
                "attributes": ["message"],
                "expression_id": bar.id,
                "method": "MASK",
            }])
        ```

        ## Import

        New Relic obfuscation rule can be imported using the rule ID, e.g.

        bash

        ```sh
        $ pulumi import newrelic:index/obfuscationRule:ObfuscationRule foo 34567
        ```

        :param str resource_name: The name of the resource.
        :param ObfuscationRuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ObfuscationRuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 actions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ObfuscationRuleActionArgs', 'ObfuscationRuleActionArgsDict']]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 filter: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ObfuscationRuleArgs.__new__(ObfuscationRuleArgs)

            __props__.__dict__["account_id"] = account_id
            if actions is None and not opts.urn:
                raise TypeError("Missing required property 'actions'")
            __props__.__dict__["actions"] = actions
            __props__.__dict__["description"] = description
            if enabled is None and not opts.urn:
                raise TypeError("Missing required property 'enabled'")
            __props__.__dict__["enabled"] = enabled
            if filter is None and not opts.urn:
                raise TypeError("Missing required property 'filter'")
            __props__.__dict__["filter"] = filter
            __props__.__dict__["name"] = name
        super(ObfuscationRule, __self__).__init__(
            'newrelic:index/obfuscationRule:ObfuscationRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[_builtins.str]] = None,
            actions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ObfuscationRuleActionArgs', 'ObfuscationRuleActionArgsDict']]]]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            filter: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None) -> 'ObfuscationRule':
        """
        Get an existing ObfuscationRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: The account id associated with the obfuscation rule.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ObfuscationRuleActionArgs', 'ObfuscationRuleActionArgsDict']]]] actions: Actions for the rule. The actions will be applied in the order specified by this list.
        :param pulumi.Input[_builtins.str] description: Description of rule.
        :param pulumi.Input[_builtins.bool] enabled: Whether the rule should be applied or not to incoming data.
        :param pulumi.Input[_builtins.str] filter: NRQL for determining whether a given log record should have obfuscation actions applied.
        :param pulumi.Input[_builtins.str] name: Name of rule.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ObfuscationRuleState.__new__(_ObfuscationRuleState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["actions"] = actions
        __props__.__dict__["description"] = description
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["filter"] = filter
        __props__.__dict__["name"] = name
        return ObfuscationRule(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[_builtins.str]:
        """
        The account id associated with the obfuscation rule.
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter
    def actions(self) -> pulumi.Output[Sequence['outputs.ObfuscationRuleAction']]:
        """
        Actions for the rule. The actions will be applied in the order specified by this list.
        """
        return pulumi.get(self, "actions")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of rule.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether the rule should be applied or not to incoming data.
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter
    def filter(self) -> pulumi.Output[_builtins.str]:
        """
        NRQL for determining whether a given log record should have obfuscation actions applied.
        """
        return pulumi.get(self, "filter")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of rule.
        """
        return pulumi.get(self, "name")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['AlertPolicyChannelArgs', 'AlertPolicyChannel']

@pulumi.input_type
class AlertPolicyChannelArgs:
    def __init__(__self__, *,
                 channel_ids: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]],
                 policy_id: pulumi.Input[_builtins.str],
                 account_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a AlertPolicyChannel resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] channel_ids: Array of channel IDs to apply to the specified policy. We recommended sorting channel IDs in ascending order to avoid drift in your state.
        :param pulumi.Input[_builtins.str] policy_id: The ID of the policy.
        :param pulumi.Input[_builtins.str] account_id: Determines the New Relic account where the alert policy channel will be created. Defaults to the account associated with the API key used.
        """
        pulumi.set(__self__, "channel_ids", channel_ids)
        pulumi.set(__self__, "policy_id", policy_id)
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)

    @_builtins.property
    @pulumi.getter(name="channelIds")
    def channel_ids(self) -> pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]:
        """
        Array of channel IDs to apply to the specified policy. We recommended sorting channel IDs in ascending order to avoid drift in your state.
        """
        return pulumi.get(self, "channel_ids")

    @channel_ids.setter
    def channel_ids(self, value: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        pulumi.set(self, "channel_ids", value)

    @_builtins.property
    @pulumi.getter(name="policyId")
    def policy_id(self) -> pulumi.Input[_builtins.str]:
        """
        The ID of the policy.
        """
        return pulumi.get(self, "policy_id")

    @policy_id.setter
    def policy_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "policy_id", value)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Determines the New Relic account where the alert policy channel will be created. Defaults to the account associated with the API key used.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)


@pulumi.input_type
class _AlertPolicyChannelState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 channel_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 policy_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering AlertPolicyChannel resources.
        :param pulumi.Input[_builtins.str] account_id: Determines the New Relic account where the alert policy channel will be created. Defaults to the account associated with the API key used.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] channel_ids: Array of channel IDs to apply to the specified policy. We recommended sorting channel IDs in ascending order to avoid drift in your state.
        :param pulumi.Input[_builtins.str] policy_id: The ID of the policy.
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if channel_ids is not None:
            pulumi.set(__self__, "channel_ids", channel_ids)
        if policy_id is not None:
            pulumi.set(__self__, "policy_id", policy_id)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Determines the New Relic account where the alert policy channel will be created. Defaults to the account associated with the API key used.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter(name="channelIds")
    def channel_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Array of channel IDs to apply to the specified policy. We recommended sorting channel IDs in ascending order to avoid drift in your state.
        """
        return pulumi.get(self, "channel_ids")

    @channel_ids.setter
    def channel_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "channel_ids", value)

    @_builtins.property
    @pulumi.getter(name="policyId")
    def policy_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID of the policy.
        """
        return pulumi.get(self, "policy_id")

    @policy_id.setter
    def policy_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "policy_id", value)


@pulumi.type_token("newrelic:index/alertPolicyChannel:AlertPolicyChannel")
class AlertPolicyChannel(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 channel_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Use this resource to map alert policies to alert channels in New Relic.

        > **WARNING:** The `AlertPolicyChannel` resource is **deprecated** and will be **removed in a future major release**. As an alternative, you can map channels to policies using the resource `Workflow`, with the channels to be mapped created using a combination of the newer resources `NotificationDestination` and `NotificationChannel`. We **strongly recommend** migrating to these new resources at the earliest. Please refer to this example for a detailed illustration on setting up channels and workflows with these resources.

        ## Example Usage

        The example below will apply multiple alert channels to an existing New Relic alert policy.

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        # Fetches the data for this policy from your New Relic account
        # and is referenced in the newrelic_alert_policy_channel block below.
        example_policy = newrelic.get_alert_policy(name="my-alert-policy")
        # Creates an email alert channel.
        email_channel = newrelic.AlertChannel("email_channel",
            name="bar",
            type="email",
            config={
                "recipients": "foo@example.com",
                "include_json_attachment": "1",
            })
        # Creates a Slack alert channel.
        slack_channel = newrelic.AlertChannel("slack_channel",
            name="slack-channel-example",
            type="slack",
            config={
                "channel": "#example-channel",
                "url": "http://example-org.slack.com",
            })
        # Applies the created channels above to the alert policy
        # referenced at the top of the config.
        foo = newrelic.AlertPolicyChannel("foo",
            policy_id=example_policy.id,
            channel_ids=[
                email_channel.id,
                slack_channel.id,
            ])
        ```

        ## Import

        Alert policy channels can be imported using the following notation: `<policyID>:<channelID>:<channelID>`, e.g.

        ```sh
        $ pulumi import newrelic:index/alertPolicyChannel:AlertPolicyChannel foo 123456:3462754:2938324
        ```
        When importing `newrelic_alert_policy_channel` resource, the attribute `channel_ids`* will be set in your Terraform state. You can import multiple channels as long as those channel IDs are included as part of the import ID hash.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: Determines the New Relic account where the alert policy channel will be created. Defaults to the account associated with the API key used.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] channel_ids: Array of channel IDs to apply to the specified policy. We recommended sorting channel IDs in ascending order to avoid drift in your state.
        :param pulumi.Input[_builtins.str] policy_id: The ID of the policy.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AlertPolicyChannelArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Use this resource to map alert policies to alert channels in New Relic.

        > **WARNING:** The `AlertPolicyChannel` resource is **deprecated** and will be **removed in a future major release**. As an alternative, you can map channels to policies using the resource `Workflow`, with the channels to be mapped created using a combination of the newer resources `NotificationDestination` and `NotificationChannel`. We **strongly recommend** migrating to these new resources at the earliest. Please refer to this example for a detailed illustration on setting up channels and workflows with these resources.

        ## Example Usage

        The example below will apply multiple alert channels to an existing New Relic alert policy.

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        # Fetches the data for this policy from your New Relic account
        # and is referenced in the newrelic_alert_policy_channel block below.
        example_policy = newrelic.get_alert_policy(name="my-alert-policy")
        # Creates an email alert channel.
        email_channel = newrelic.AlertChannel("email_channel",
            name="bar",
            type="email",
            config={
                "recipients": "foo@example.com",
                "include_json_attachment": "1",
            })
        # Creates a Slack alert channel.
        slack_channel = newrelic.AlertChannel("slack_channel",
            name="slack-channel-example",
            type="slack",
            config={
                "channel": "#example-channel",
                "url": "http://example-org.slack.com",
            })
        # Applies the created channels above to the alert policy
        # referenced at the top of the config.
        foo = newrelic.AlertPolicyChannel("foo",
            policy_id=example_policy.id,
            channel_ids=[
                email_channel.id,
                slack_channel.id,
            ])
        ```

        ## Import

        Alert policy channels can be imported using the following notation: `<policyID>:<channelID>:<channelID>`, e.g.

        ```sh
        $ pulumi import newrelic:index/alertPolicyChannel:AlertPolicyChannel foo 123456:3462754:2938324
        ```
        When importing `newrelic_alert_policy_channel` resource, the attribute `channel_ids`* will be set in your Terraform state. You can import multiple channels as long as those channel IDs are included as part of the import ID hash.

        :param str resource_name: The name of the resource.
        :param AlertPolicyChannelArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AlertPolicyChannelArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 channel_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 policy_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AlertPolicyChannelArgs.__new__(AlertPolicyChannelArgs)

            __props__.__dict__["account_id"] = account_id
            if channel_ids is None and not opts.urn:
                raise TypeError("Missing required property 'channel_ids'")
            __props__.__dict__["channel_ids"] = channel_ids
            if policy_id is None and not opts.urn:
                raise TypeError("Missing required property 'policy_id'")
            __props__.__dict__["policy_id"] = policy_id
        super(AlertPolicyChannel, __self__).__init__(
            'newrelic:index/alertPolicyChannel:AlertPolicyChannel',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[_builtins.str]] = None,
            channel_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            policy_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'AlertPolicyChannel':
        """
        Get an existing AlertPolicyChannel resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: Determines the New Relic account where the alert policy channel will be created. Defaults to the account associated with the API key used.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] channel_ids: Array of channel IDs to apply to the specified policy. We recommended sorting channel IDs in ascending order to avoid drift in your state.
        :param pulumi.Input[_builtins.str] policy_id: The ID of the policy.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AlertPolicyChannelState.__new__(_AlertPolicyChannelState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["channel_ids"] = channel_ids
        __props__.__dict__["policy_id"] = policy_id
        return AlertPolicyChannel(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[_builtins.str]:
        """
        Determines the New Relic account where the alert policy channel will be created. Defaults to the account associated with the API key used.
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter(name="channelIds")
    def channel_ids(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        Array of channel IDs to apply to the specified policy. We recommended sorting channel IDs in ascending order to avoid drift in your state.
        """
        return pulumi.get(self, "channel_ids")

    @_builtins.property
    @pulumi.getter(name="policyId")
    def policy_id(self) -> pulumi.Output[_builtins.str]:
        """
        The ID of the policy.
        """
        return pulumi.get(self, "policy_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['EventsToMetricsRuleArgs', 'EventsToMetricsRule']

@pulumi.input_type
class EventsToMetricsRuleArgs:
    def __init__(__self__, *,
                 nrql: pulumi.Input[_builtins.str],
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a EventsToMetricsRule resource.
        :param pulumi.Input[_builtins.str] nrql: Explains how to create metrics from events.
        :param pulumi.Input[_builtins.str] account_id: Account with the event and where the metrics will be put.
        :param pulumi.Input[_builtins.str] description: Provides additional information about the rule.
        :param pulumi.Input[_builtins.bool] enabled: True means this rule is enabled. False means the rule is currently not creating metrics.
        :param pulumi.Input[_builtins.str] name: The name of the rule. This must be unique within an account.
        """
        pulumi.set(__self__, "nrql", nrql)
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @_builtins.property
    @pulumi.getter
    def nrql(self) -> pulumi.Input[_builtins.str]:
        """
        Explains how to create metrics from events.
        """
        return pulumi.get(self, "nrql")

    @nrql.setter
    def nrql(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "nrql", value)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Account with the event and where the metrics will be put.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Provides additional information about the rule.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        True means this rule is enabled. False means the rule is currently not creating metrics.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the rule. This must be unique within an account.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _EventsToMetricsRuleState:
    def __init__(__self__, *,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 nrql: Optional[pulumi.Input[_builtins.str]] = None,
                 rule_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering EventsToMetricsRule resources.
        :param pulumi.Input[_builtins.str] account_id: Account with the event and where the metrics will be put.
        :param pulumi.Input[_builtins.str] description: Provides additional information about the rule.
        :param pulumi.Input[_builtins.bool] enabled: True means this rule is enabled. False means the rule is currently not creating metrics.
        :param pulumi.Input[_builtins.str] name: The name of the rule. This must be unique within an account.
        :param pulumi.Input[_builtins.str] nrql: Explains how to create metrics from events.
        :param pulumi.Input[_builtins.str] rule_id: The id, uniquely identifying the rule.
        """
        if account_id is not None:
            pulumi.set(__self__, "account_id", account_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if nrql is not None:
            pulumi.set(__self__, "nrql", nrql)
        if rule_id is not None:
            pulumi.set(__self__, "rule_id", rule_id)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Account with the event and where the metrics will be put.
        """
        return pulumi.get(self, "account_id")

    @account_id.setter
    def account_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "account_id", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Provides additional information about the rule.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        True means this rule is enabled. False means the rule is currently not creating metrics.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enabled", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The name of the rule. This must be unique within an account.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def nrql(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Explains how to create metrics from events.
        """
        return pulumi.get(self, "nrql")

    @nrql.setter
    def nrql(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "nrql", value)

    @_builtins.property
    @pulumi.getter(name="ruleId")
    def rule_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The id, uniquely identifying the rule.
        """
        return pulumi.get(self, "rule_id")

    @rule_id.setter
    def rule_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "rule_id", value)


@pulumi.type_token("newrelic:index/eventsToMetricsRule:EventsToMetricsRule")
class EventsToMetricsRule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 nrql: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Use this resource to create, update, and delete New Relic Events to Metrics rules.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.EventsToMetricsRule("foo",
            account_id="12345",
            name="Example events to metrics rule",
            description="Example description",
            nrql="SELECT uniqueCount(account_id) AS ``Transaction.account_id`` FROM Transaction FACET appName, name")
        ```

        ## Import

        New Relic Events to Metrics rules can be imported using a concatenated string of the format

         `<account_id>:<rule_id>`, e.g.

        bash

        ```sh
        $ pulumi import newrelic:index/eventsToMetricsRule:EventsToMetricsRule foo 12345:34567
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: Account with the event and where the metrics will be put.
        :param pulumi.Input[_builtins.str] description: Provides additional information about the rule.
        :param pulumi.Input[_builtins.bool] enabled: True means this rule is enabled. False means the rule is currently not creating metrics.
        :param pulumi.Input[_builtins.str] name: The name of the rule. This must be unique within an account.
        :param pulumi.Input[_builtins.str] nrql: Explains how to create metrics from events.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EventsToMetricsRuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Use this resource to create, update, and delete New Relic Events to Metrics rules.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_newrelic as newrelic

        foo = newrelic.EventsToMetricsRule("foo",
            account_id="12345",
            name="Example events to metrics rule",
            description="Example description",
            nrql="SELECT uniqueCount(account_id) AS ``Transaction.account_id`` FROM Transaction FACET appName, name")
        ```

        ## Import

        New Relic Events to Metrics rules can be imported using a concatenated string of the format

         `<account_id>:<rule_id>`, e.g.

        bash

        ```sh
        $ pulumi import newrelic:index/eventsToMetricsRule:EventsToMetricsRule foo 12345:34567
        ```

        :param str resource_name: The name of the resource.
        :param EventsToMetricsRuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EventsToMetricsRuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 account_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 nrql: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EventsToMetricsRuleArgs.__new__(EventsToMetricsRuleArgs)

            __props__.__dict__["account_id"] = account_id
            __props__.__dict__["description"] = description
            __props__.__dict__["enabled"] = enabled
            __props__.__dict__["name"] = name
            if nrql is None and not opts.urn:
                raise TypeError("Missing required property 'nrql'")
            __props__.__dict__["nrql"] = nrql
            __props__.__dict__["rule_id"] = None
        super(EventsToMetricsRule, __self__).__init__(
            'newrelic:index/eventsToMetricsRule:EventsToMetricsRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            account_id: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            nrql: Optional[pulumi.Input[_builtins.str]] = None,
            rule_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'EventsToMetricsRule':
        """
        Get an existing EventsToMetricsRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] account_id: Account with the event and where the metrics will be put.
        :param pulumi.Input[_builtins.str] description: Provides additional information about the rule.
        :param pulumi.Input[_builtins.bool] enabled: True means this rule is enabled. False means the rule is currently not creating metrics.
        :param pulumi.Input[_builtins.str] name: The name of the rule. This must be unique within an account.
        :param pulumi.Input[_builtins.str] nrql: Explains how to create metrics from events.
        :param pulumi.Input[_builtins.str] rule_id: The id, uniquely identifying the rule.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EventsToMetricsRuleState.__new__(_EventsToMetricsRuleState)

        __props__.__dict__["account_id"] = account_id
        __props__.__dict__["description"] = description
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["name"] = name
        __props__.__dict__["nrql"] = nrql
        __props__.__dict__["rule_id"] = rule_id
        return EventsToMetricsRule(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accountId")
    def account_id(self) -> pulumi.Output[_builtins.str]:
        """
        Account with the event and where the metrics will be put.
        """
        return pulumi.get(self, "account_id")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Provides additional information about the rule.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        True means this rule is enabled. False means the rule is currently not creating metrics.
        """
        return pulumi.get(self, "enabled")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        The name of the rule. This must be unique within an account.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def nrql(self) -> pulumi.Output[_builtins.str]:
        """
        Explains how to create metrics from events.
        """
        return pulumi.get(self, "nrql")

    @_builtins.property
    @pulumi.getter(name="ruleId")
    def rule_id(self) -> pulumi.Output[_builtins.str]:
        """
        The id, uniquely identifying the rule.
        """
        return pulumi.get(self, "rule_id")

